Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(364)

Unified Diff: base/metrics/field_trial.h

Issue 1984003002: Use low entropy for studies that send experiment IDs to Google properties. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | base/metrics/field_trial.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/metrics/field_trial.h
diff --git a/base/metrics/field_trial.h b/base/metrics/field_trial.h
index 808c7789740c23eb8ef42b21647f140875778658..fc6237a51343ee7d7753727ef96ba4c96b5025d9 100644
--- a/base/metrics/field_trial.h
+++ b/base/metrics/field_trial.h
@@ -393,9 +393,12 @@ class BASE_EXPORT FieldTrialList {
// used on one-time randomized field trials (instead of a hash of the trial
// name, which is used otherwise or if |randomization_seed| has value 0). The
// |randomization_seed| value (other than 0) should never be the same for two
// trials, else this would result in correlated group assignments.
// Note: Using a custom randomization seed is only supported by the
// PermutedEntropyProvider (which is used when UMA is not enabled).
static FieldTrial* FactoryGetFieldTrialWithRandomizationSeed(
const std::string& trial_name,
FieldTrial::Probability total_probability,
@@ -405,7 +408,8 @@ class BASE_EXPORT FieldTrialList {
const int day_of_month,
FieldTrial::RandomizationType randomization_type,
uint32_t randomization_seed,
- int* default_group_number);
+ int* default_group_number,
+ const FieldTrial::EntropyProvider* override_entropy_provider);
// The Find() method can be used to test to see if a named trial was already
// registered, or to retrieve a pointer to it from the global map.
« no previous file with comments | « no previous file | base/metrics/field_trial.cc » ('j') | no next file with comments »
@@ -393,9 +393,12 @@ class BASE_EXPORT FieldTrialList {
// name, which is used otherwise or if |randomization_seed| has value 0). The
// |randomization_seed| value (other than 0) should never be the same for two
- // trials, else this would result in correlated group assignments.
- // Note: Using a custom randomization seed is only supported by the
- // PermutedEntropyProvider (which is used when UMA is not enabled).
+ // trials, else this would result in correlated group assignments. Note:
+ // Using a custom randomization seed is only supported by the
+ // PermutedEntropyProvider (which is used when UMA is not enabled). If
+ // |override_entropy_provider| is not null, then it will be used for
+ // randomization instead of the provider given when the FieldTrialList was
+ // instanciated.
static FieldTrial* FactoryGetFieldTrialWithRandomizationSeed(
const std::string& trial_name,

Powered by Google App Engine
This is Rietveld 408576698